static const char *const kEoB1ChargenStrings1AmigaEnglish[9] = {
	"Your party is\rcomplete. Select\rthe PLAY button\ror press 'P' to\rstart the game.",
	"          ",
	"AC\rHP\rLVL",
	"%s\r%d\r%d\r%d\r%d\r%d",
	"%d\r%d",
	"%d",
	"%d/%d",
	"%d/%d/%d",
	"Select the box of\rthe character you\rwish to create or\rview."
};

static const StringListProvider kEoB1ChargenStrings1AmigaEnglishProvider = { ARRAYSIZE(kEoB1ChargenStrings1AmigaEnglish), kEoB1ChargenStrings1AmigaEnglish };

static const char *const kEoB1ChargenStrings2AmigaEnglish[12] = {
	"%s",
	"%d",
	"%s",
	"%d",
	"%d",
	"%d",
	"%s",
	"%d",
	"SELECT RACE:",
	"SELECT CLASS:",
	"SELECT ALIGNMENT:",
	"Name:"
};



static const StringListProvider kEoB1ChargenStrings2AmigaEnglishProvider = { ARRAYSIZE(kEoB1ChargenStrings2AmigaEnglish), kEoB1ChargenStrings2AmigaEnglish };

static const char *const kEoB1ChargenStatStringsAmigaEnglish[12] = {
	"STR",
	"INT",
	"WIS",
	"DEX",
	"CON",
	"CHA",
	"STRENGTH",
	"INTELLIGENCE",
	"WISDOM",
	"DEXTERITY",
	"CONSTITUTION",
	"CHARISMA"
};

static const StringListProvider kEoB1ChargenStatStringsAmigaEnglishProvider = { ARRAYSIZE(kEoB1ChargenStatStringsAmigaEnglish), kEoB1ChargenStatStringsAmigaEnglish };

static const char *const kEoB1ChargenRaceSexStringsAmigaEnglish[12] = {
	"HUMAN MALE",
	"HUMAN FEMALE",
	"ELF MALE",
	"ELF FEMALE",
	"HALF-ELF MALE",
	"HALF-ELF FEMALE",
	"DWARF MALE",
	"DWARF FEMALE",
	"GNOME MALE",
	"GNOME FEMALE",
	"HALFLING MALE",
	"HALFLING FEMALE"
};

static const StringListProvider kEoB1ChargenRaceSexStringsAmigaEnglishProvider = { ARRAYSIZE(kEoB1ChargenRaceSexStringsAmigaEnglish), kEoB1ChargenRaceSexStringsAmigaEnglish };

static const char *const kEoB1ChargenClassStringsAmigaEnglish[21] = {
	"FIGHTER",
	"RANGER",
	"PALADIN",
	"MAGE",
	"CLERIC",
	"THIEF",
	"FIGHTER/CLERIC",
	"FIGHTER/THIEF",
	"FIGHTER/MAGE",
	"FIGHTER/MAGE/THIEF",
	"THIEF/MAGE",
	"CLERIC/THIEF",
	"FIGHTER/CLERIC/MAGE",
	"RANGER/CLERIC",
	"CLERIC/MAGE",
	"FIGHTER",
	"MAGE",
	"CLERIC",
	"THIEF",
	"PALADIN",
	"RANGER"
};

static const StringListProvider kEoB1ChargenClassStringsAmigaEnglishProvider = { ARRAYSIZE(kEoB1ChargenClassStringsAmigaEnglish), kEoB1ChargenClassStringsAmigaEnglish };

static const char *const kEoB1ChargenAlignmentStringsAmigaEnglish[9] = {
	"LAWFUL GOOD",
	"NEUTRAL GOOD",
	"CHAOTIC GOOD",
	"LAWFUL NEUTRAL",
	"TRUE NEUTRAL",
	"CHAOTIC NEUTRAL",
	"LAWFUL EVIL",
	"NEUTRAL EVIL",
	"CHAOTIC EVIL"
};

static const StringListProvider kEoB1ChargenAlignmentStringsAmigaEnglishProvider = { ARRAYSIZE(kEoB1ChargenAlignmentStringsAmigaEnglish), kEoB1ChargenAlignmentStringsAmigaEnglish };

static const char *const kEoB1ChargenEnterGameStringsAmigaEnglish[1] = {
	"  Entering game.\r  Please wait."
};

static const StringListProvider kEoB1ChargenEnterGameStringsAmigaEnglishProvider = { ARRAYSIZE(kEoB1ChargenEnterGameStringsAmigaEnglish), kEoB1ChargenEnterGameStringsAmigaEnglish };

static const char *const kEoB1MainMenuStringsAmigaEnglish[3] = {
	"LOAD GAME IN PROGRESS\r",
	"START A NEW PARTY\r",
	"EXIT TO DOS\r"
};

static const StringListProvider kEoB1MainMenuStringsAmigaEnglishProvider = { ARRAYSIZE(kEoB1MainMenuStringsAmigaEnglish), kEoB1MainMenuStringsAmigaEnglish };

static const char *const kEoB1BonusStringsAmigaEnglish[3] = {
	"Congratulations on completing all 12 Beholder Bonuses.\r\rThe names of the character in your winning Beholder Bonus party are:\r\r",
	"\r",
	"\r\rPassword: %04x\r"
};

static const StringListProvider kEoB1BonusStringsAmigaEnglishProvider = { ARRAYSIZE(kEoB1BonusStringsAmigaEnglish), kEoB1BonusStringsAmigaEnglish };

static const char *const kEoB1TurnUndeadStringAmigaEnglish[1] = {
	"\x06\x06""%s uses the power to turn undead!""\x06\x1F""\r"
};

static const StringListProvider kEoB1TurnUndeadStringAmigaEnglishProvider = { ARRAYSIZE(kEoB1TurnUndeadStringAmigaEnglish), kEoB1TurnUndeadStringAmigaEnglish };

static const char *const kEoB1Npc0StringsAmigaEnglish[2] = {
	"\r     I wish you luck in your travels.",
	"Which should be resurrected?"
};

static const StringListProvider kEoB1Npc0StringsAmigaEnglishProvider = { ARRAYSIZE(kEoB1Npc0StringsAmigaEnglish), kEoB1Npc0StringsAmigaEnglish };

static const char *const kEoB1Npc11StringsAmigaEnglish[3] = {
	"Tend his wounds",
	"Talk",
	"Leave"
};

static const StringListProvider kEoB1Npc11StringsAmigaEnglishProvider = { ARRAYSIZE(kEoB1Npc11StringsAmigaEnglish), kEoB1Npc11StringsAmigaEnglish };

static const char *const kEoB1Npc12StringsAmigaEnglish[2] = {
	"Tend his wounds",
	"Leave"
};

static const StringListProvider kEoB1Npc12StringsAmigaEnglishProvider = { ARRAYSIZE(kEoB1Npc12StringsAmigaEnglish), kEoB1Npc12StringsAmigaEnglish };

static const char *const kEoB1Npc21StringsAmigaEnglish[2] = {
	"Hear proposal",
	"Leave"
};

static const StringListProvider kEoB1Npc21StringsAmigaEnglishProvider = { ARRAYSIZE(kEoB1Npc21StringsAmigaEnglish), kEoB1Npc21StringsAmigaEnglish };

static const char *const kEoB1Npc22StringsAmigaEnglish[2] = {
	"Help him",
	"Leave"
};

static const StringListProvider kEoB1Npc22StringsAmigaEnglishProvider = { ARRAYSIZE(kEoB1Npc22StringsAmigaEnglish), kEoB1Npc22StringsAmigaEnglish };

static const char *const kEoB1Npc31StringsAmigaEnglish[2] = {
	"Heal Party",
	"Leave"
};

static const StringListProvider kEoB1Npc31StringsAmigaEnglishProvider = { ARRAYSIZE(kEoB1Npc31StringsAmigaEnglish), kEoB1Npc31StringsAmigaEnglish };

static const char *const kEoB1Npc32StringsAmigaEnglish[3] = {
	"Heal Party",
	"Resurrect Dead",
	"Leave"
};

static const StringListProvider kEoB1Npc32StringsAmigaEnglishProvider = { ARRAYSIZE(kEoB1Npc32StringsAmigaEnglish), kEoB1Npc32StringsAmigaEnglish };

static const char *const kEoB1Npc4StringsAmigaEnglish[2] = {
	"Attack",
	"Bribe"
};

static const StringListProvider kEoB1Npc4StringsAmigaEnglishProvider = { ARRAYSIZE(kEoB1Npc4StringsAmigaEnglish), kEoB1Npc4StringsAmigaEnglish };

static const char *const kEoB1Npc5StringsAmigaEnglish[3] = {
	"Kill her",
	"Hear her out",
	"Let her go"
};

static const StringListProvider kEoB1Npc5StringsAmigaEnglishProvider = { ARRAYSIZE(kEoB1Npc5StringsAmigaEnglish), kEoB1Npc5StringsAmigaEnglish };

static const char *const kEoB1Npc6StringsAmigaEnglish[2] = {
	"Surrender",
	"Attack"
};

static const StringListProvider kEoB1Npc6StringsAmigaEnglishProvider = { ARRAYSIZE(kEoB1Npc6StringsAmigaEnglish), kEoB1Npc6StringsAmigaEnglish };

static const char *const kEoB1Npc7StringsAmigaEnglish[3] = {
	"Free Him",
	"Kill Him",
	"Leave"
};

static const StringListProvider kEoB1Npc7StringsAmigaEnglishProvider = { ARRAYSIZE(kEoB1Npc7StringsAmigaEnglish), kEoB1Npc7StringsAmigaEnglish };

static const char *const kEoB1PryDoorStringsAmigaEnglish[7] = {
	"Nobody is able to force the door.\r",
	"The party forces the door.\r",
	"%s forces the door!\r",
	"The party tries to force the door and fails.\r",
	"You can't put that item there.\r",
	"The item is too large to fit.\r",
	"No one is able to pry this door open.\r"
};

static const StringListProvider kEoB1PryDoorStringsAmigaEnglishProvider = { ARRAYSIZE(kEoB1PryDoorStringsAmigaEnglish), kEoB1PryDoorStringsAmigaEnglish };

static const char *const kEoB1WarningStringsAmigaEnglish[3] = {
	"You can't go that way.\r",
	"%s isn't capable of eating food!\r",
	"You may only eat food!\r"
};

static const StringListProvider kEoB1WarningStringsAmigaEnglishProvider = { ARRAYSIZE(kEoB1WarningStringsAmigaEnglish), kEoB1WarningStringsAmigaEnglish };

static const char *const kEoB1ItemSuffixStringsRingsAmigaEnglish[4] = {
	"Adornment",
	"Wizardry",
	"Sustenance",
	"Feather Fall"
};

static const StringListProvider kEoB1ItemSuffixStringsRingsAmigaEnglishProvider = { ARRAYSIZE(kEoB1ItemSuffixStringsRingsAmigaEnglish), kEoB1ItemSuffixStringsRingsAmigaEnglish };

static const char *const kEoB1ItemSuffixStringsPotionsAmigaEnglish[8] = {
	"Giant Strength",
	"Healing",
	"Extra Healing",
	"Poison",
	"Vitality",
	"Speed",
	"Invisibility",
	"Cure Poison"
};

static const StringListProvider kEoB1ItemSuffixStringsPotionsAmigaEnglishProvider = { ARRAYSIZE(kEoB1ItemSuffixStringsPotionsAmigaEnglish), kEoB1ItemSuffixStringsPotionsAmigaEnglish };

static const char *const kEoB1ItemSuffixStringsWandsAmigaEnglish[7] = {
	"Stick",
	"Lightning",
	"Frost",
	"Curing",
	"Fireball",
	"Silvias",
	"Magic Missile"
};

static const StringListProvider kEoB1ItemSuffixStringsWandsAmigaEnglishProvider = { ARRAYSIZE(kEoB1ItemSuffixStringsWandsAmigaEnglish), kEoB1ItemSuffixStringsWandsAmigaEnglish };

static const char *const kEoB1RipItemStringsAmigaEnglish[3] = {
	"%s has lost her ",
	"%s has lost his ",
	".\r"
};

static const StringListProvider kEoB1RipItemStringsAmigaEnglishProvider = { ARRAYSIZE(kEoB1RipItemStringsAmigaEnglish), kEoB1RipItemStringsAmigaEnglish };

static const char *const kEoB1CursedStringAmigaEnglish[1] = {
	"Cursed %s %d"
};

static const StringListProvider kEoB1CursedStringAmigaEnglishProvider = { ARRAYSIZE(kEoB1CursedStringAmigaEnglish), kEoB1CursedStringAmigaEnglish };

static const char *const kEoB1MagicObjectStringsAmigaEnglish[5] = {
	"Mage Scroll",
	"Cleric Scroll",
	"Ring",
	"Potion",
	"Wand"
};

static const StringListProvider kEoB1MagicObjectStringsAmigaEnglishProvider = { ARRAYSIZE(kEoB1MagicObjectStringsAmigaEnglish), kEoB1MagicObjectStringsAmigaEnglish };

static const char *const kEoB1MagicObjectString5AmigaEnglish[1] = {
	"Stick"
};

static const StringListProvider kEoB1MagicObjectString5AmigaEnglishProvider = { ARRAYSIZE(kEoB1MagicObjectString5AmigaEnglish), kEoB1MagicObjectString5AmigaEnglish };

static const char *const kEoB1PatternSuffixAmigaEnglish[1] = {
	"%s of %s"
};

static const StringListProvider kEoB1PatternSuffixAmigaEnglishProvider = { ARRAYSIZE(kEoB1PatternSuffixAmigaEnglish), kEoB1PatternSuffixAmigaEnglish };

static const char *const kEoB1PatternGrFix1AmigaEnglish[1] = {
	"%s of %s"
};

static const StringListProvider kEoB1PatternGrFix1AmigaEnglishProvider = { ARRAYSIZE(kEoB1PatternGrFix1AmigaEnglish), kEoB1PatternGrFix1AmigaEnglish };

static const char *const kEoB1PatternGrFix2AmigaEnglish[1] = {
	"%s of %s"
};

static const StringListProvider kEoB1PatternGrFix2AmigaEnglishProvider = { ARRAYSIZE(kEoB1PatternGrFix2AmigaEnglish), kEoB1PatternGrFix2AmigaEnglish };

static const char *const kEoB1ValidateArmorStringAmigaEnglish[1] = {
	"%s can't wear that type of armor.\r"
};

static const StringListProvider kEoB1ValidateArmorStringAmigaEnglishProvider = { ARRAYSIZE(kEoB1ValidateArmorStringAmigaEnglish), kEoB1ValidateArmorStringAmigaEnglish };

static const char *const kEoB1ValidateNoDropStringAmigaEnglish[1] = {
	"You can't put that item there.\r"
};

static const StringListProvider kEoB1ValidateNoDropStringAmigaEnglishProvider = { ARRAYSIZE(kEoB1ValidateNoDropStringAmigaEnglish), kEoB1ValidateNoDropStringAmigaEnglish };

static const char *const kEoB1PotionStringsAmigaEnglish[2] = {
	"poisoned",
	"%s feels %s!\r"
};

static const StringListProvider kEoB1PotionStringsAmigaEnglishProvider = { ARRAYSIZE(kEoB1PotionStringsAmigaEnglish), kEoB1PotionStringsAmigaEnglish };

static const char *const kEoB1WandStringsAmigaEnglish[2] = {
	"The wand has no apparent magical effect\r",
	"no effect.\r"
};

static const StringListProvider kEoB1WandStringsAmigaEnglishProvider = { ARRAYSIZE(kEoB1WandStringsAmigaEnglish), kEoB1WandStringsAmigaEnglish };

static const char *const kEoB1ItemMisuseStringsAmigaEnglish[3] = {
	"%s can not use this item.\r",
	"This item automatically used when worn.\r",
	"This item is not used in this way.\r"
};

static const StringListProvider kEoB1ItemMisuseStringsAmigaEnglishProvider = { ARRAYSIZE(kEoB1ItemMisuseStringsAmigaEnglish), kEoB1ItemMisuseStringsAmigaEnglish };

static const char *const kEoB1TakenStringsAmigaEnglish[1] = {
	" taken.\r"
};

static const StringListProvider kEoB1TakenStringsAmigaEnglishProvider = { ARRAYSIZE(kEoB1TakenStringsAmigaEnglish), kEoB1TakenStringsAmigaEnglish };

static const char *const kEoB1PotionEffectStringsAmigaEnglish[8] = {
	"much stronger",
	"better",
	"much better",
	"ill for a moment",
	"no longer hungry",
	"fast and agile",
	"transparent",
	"better"
};

static const StringListProvider kEoB1PotionEffectStringsAmigaEnglishProvider = { ARRAYSIZE(kEoB1PotionEffectStringsAmigaEnglish), kEoB1PotionEffectStringsAmigaEnglish };

static const char *const kEoB1YesNoStringsAmigaEnglish[2] = {
	"yes",
	"no"
};

static const StringListProvider kEoB1YesNoStringsAmigaEnglishProvider = { ARRAYSIZE(kEoB1YesNoStringsAmigaEnglish), kEoB1YesNoStringsAmigaEnglish };

static const char *const kEoB1MoreStringsAmigaEnglish[1] = {
	"MORE"
};

static const StringListProvider kEoB1MoreStringsAmigaEnglishProvider = { ARRAYSIZE(kEoB1MoreStringsAmigaEnglish), kEoB1MoreStringsAmigaEnglish };

static const char *const kEoB1NpcMaxStringsAmigaEnglish[1] = {
	"You may only have six characters in your party.  Select the one you wish to drop."
};

static const StringListProvider kEoB1NpcMaxStringsAmigaEnglishProvider = { ARRAYSIZE(kEoB1NpcMaxStringsAmigaEnglish), kEoB1NpcMaxStringsAmigaEnglish };

static const char *const kEoB1NpcJoinStringsAmigaEnglish[1] = {
	"%s joins the party.\r"
};

static const StringListProvider kEoB1NpcJoinStringsAmigaEnglishProvider = { ARRAYSIZE(kEoB1NpcJoinStringsAmigaEnglish), kEoB1NpcJoinStringsAmigaEnglish };

static const char *const kEoB1CancelStringsAmigaEnglish[1] = {
	"CANCEL"
};

static const StringListProvider kEoB1CancelStringsAmigaEnglishProvider = { ARRAYSIZE(kEoB1CancelStringsAmigaEnglish), kEoB1CancelStringsAmigaEnglish };

static const char *const kEoB1MenuStringsMainAmigaEnglish[8] = {
	"Select Option:",
	"Rest Party",
	"Memorize Spells",
	"Pray for Spells",
	"Scribe Scrolls",
	"Preferences",
	"Game Options",
	"Exit"
};

static const StringListProvider kEoB1MenuStringsMainAmigaEnglishProvider = { ARRAYSIZE(kEoB1MenuStringsMainAmigaEnglish), kEoB1MenuStringsMainAmigaEnglish };

static const char *const kEoB1MenuStringsSaveLoadAmigaEnglish[8] = {
	"Load Game",
	"Save Game",
	"Drop Character",
	"Quit Game",
	"Game Options:",
	"\r   Game saved.",
	"\r Save game\r failure!",
	"\r Load game\r failure!"
};

static const StringListProvider kEoB1MenuStringsSaveLoadAmigaEnglishProvider = { ARRAYSIZE(kEoB1MenuStringsSaveLoadAmigaEnglish), kEoB1MenuStringsSaveLoadAmigaEnglish };

static const char *const kEoB1MenuStringsOnOffAmigaEnglish[2] = {
	"ON",
	"OFF"
};

static const StringListProvider kEoB1MenuStringsOnOffAmigaEnglishProvider = { ARRAYSIZE(kEoB1MenuStringsOnOffAmigaEnglish), kEoB1MenuStringsOnOffAmigaEnglish };

static const char *const kEoB1MenuStringsSpellsAmigaEnglish[17] = {
	"\r\r Select a character\r from your party who\r would like to learn\r spells.",
	"\r Your Paladin is \r too low a level\r for spells.",
	"\r\r The Mage has no\r Spell Book!",
	"\r\r\r Select a character\r from your party\r who would like to\r pray for spells.",
	"\r You don't have\r any Cleric able\r to pray in your\r party.",
	"\r You don't have\r any Mage able to\r learn spells.",
	" An unconscious\r or dead Mage\r cannot memorize\r spells.",
	" An unconscious\r or dead Cleric\r cannot pray for\r spells.",
	"1",
	"2",
	"3",
	"4",
	"5",
	"Clear",
	"Spells Available:",
	"Yes",
	"No"
};

static const StringListProvider kEoB1MenuStringsSpellsAmigaEnglishProvider = { ARRAYSIZE(kEoB1MenuStringsSpellsAmigaEnglish), kEoB1MenuStringsSpellsAmigaEnglish };

static const char *const kEoB1MenuStringsRestAmigaEnglish[5] = {
	"\rWill your healers\rheal the party?",
	" Someone is still\r injured. Rest\r until healed?",
	"Resting party.",
	"\r All characters\r are fully\r rested.",
	" Your party needs\r to rest to gain\r spells."
};

static const StringListProvider kEoB1MenuStringsRestAmigaEnglishProvider = { ARRAYSIZE(kEoB1MenuStringsRestAmigaEnglish), kEoB1MenuStringsRestAmigaEnglish };

static const char *const kEoB1MenuStringsDropAmigaEnglish[1] = {
	" You cannot have\r less than four\r characters."
};

static const StringListProvider kEoB1MenuStringsDropAmigaEnglishProvider = { ARRAYSIZE(kEoB1MenuStringsDropAmigaEnglish), kEoB1MenuStringsDropAmigaEnglish };

static const char *const kEoB1MenuStringsExitAmigaEnglish[1] = {
	" Are you sure you\r wish to exit the\r game?"
};

static const StringListProvider kEoB1MenuStringsExitAmigaEnglishProvider = { ARRAYSIZE(kEoB1MenuStringsExitAmigaEnglish), kEoB1MenuStringsExitAmigaEnglish };

static const char *const kEoB1MenuStringsStarveAmigaEnglish[1] = {
	" Your party is\r starving. Do you\r wish to continue\r resting?"
};

static const StringListProvider kEoB1MenuStringsStarveAmigaEnglishProvider = { ARRAYSIZE(kEoB1MenuStringsStarveAmigaEnglish), kEoB1MenuStringsStarveAmigaEnglish };

static const char *const kEoB1MenuStringsScribeAmigaEnglish[5] = {
	"Select the scroll(s)\ryou wish to scribe.",
	"\r\r\r Select a Mage\r from your party\r who would like to\r scribe spells.",
	" You don't have\r any scrolls to\r be scribed.",
	" You don't have\r any scrolls that\r this Mage needs.",
	"\r You don't have\r any Mage able to\r scribe scrolls."
};

static const StringListProvider kEoB1MenuStringsScribeAmigaEnglishProvider = { ARRAYSIZE(kEoB1MenuStringsScribeAmigaEnglish), kEoB1MenuStringsScribeAmigaEnglish };

static const char *const kEoB1MenuStringsDrop2AmigaEnglish[3] = {
	" Select the\r character you\r wish to drop.",
	" Are you sure you\r wish to SAVE the\r game?",
	" Are you sure you\r wish to LOAD a\r saved game?"
};

static const StringListProvider kEoB1MenuStringsDrop2AmigaEnglishProvider = { ARRAYSIZE(kEoB1MenuStringsDrop2AmigaEnglish), kEoB1MenuStringsDrop2AmigaEnglish };

static const char *const kEoB1MenuStringsHeadAmigaEnglish[3] = {
	"Camp:",
	"Preferences:",
	"Game Options:"
};

static const StringListProvider kEoB1MenuStringsHeadAmigaEnglishProvider = { ARRAYSIZE(kEoB1MenuStringsHeadAmigaEnglish), kEoB1MenuStringsHeadAmigaEnglish };

static const char *const kEoB1MenuStringsPoisonAmigaEnglish[1] = {
	"Poisoned party\rmembers will die!\rRest anyway?"
};

static const StringListProvider kEoB1MenuStringsPoisonAmigaEnglishProvider = { ARRAYSIZE(kEoB1MenuStringsPoisonAmigaEnglish), kEoB1MenuStringsPoisonAmigaEnglish };

static const char *const kEoB1MenuStringsMgcAmigaEnglish[2] = {
	"%-18s %1d",
	"%d of %d Remaining.  "
};

static const StringListProvider kEoB1MenuStringsMgcAmigaEnglishProvider = { ARRAYSIZE(kEoB1MenuStringsMgcAmigaEnglish), kEoB1MenuStringsMgcAmigaEnglish };

static const char *const kEoB1MenuStringsPrefsAmigaEnglish[4] = {
	"Tunes are %-3s",
	"Sounds are %-3s",
	"Bar Graphs are %-3s",
	""
};

static const StringListProvider kEoB1MenuStringsPrefsAmigaEnglishProvider = { ARRAYSIZE(kEoB1MenuStringsPrefsAmigaEnglish), kEoB1MenuStringsPrefsAmigaEnglish };

static const char *const kEoB1MenuStringsRest2AmigaEnglish[4] = {
	"%s gained %s.\r",
	"%s memorized %s.\r",
	"%s casts healing on %s.\r",
	"Hours rested: %-4d"
};

static const StringListProvider kEoB1MenuStringsRest2AmigaEnglishProvider = { ARRAYSIZE(kEoB1MenuStringsRest2AmigaEnglish), kEoB1MenuStringsRest2AmigaEnglish };

static const char *const kEoB1MenuStringsRest4AmigaEnglish[1] = {
	"\rYou can't rest here, monsters are near.\r"
};

static const StringListProvider kEoB1MenuStringsRest4AmigaEnglishProvider = { ARRAYSIZE(kEoB1MenuStringsRest4AmigaEnglish), kEoB1MenuStringsRest4AmigaEnglish };

static const char *const kEoB1MenuStringsDefeatAmigaEnglish[1] = {
	"All of your party has been defeated.  The minions of evil will be able to carry out their plans unhindered!\r"
};

static const StringListProvider kEoB1MenuStringsDefeatAmigaEnglishProvider = { ARRAYSIZE(kEoB1MenuStringsDefeatAmigaEnglish), kEoB1MenuStringsDefeatAmigaEnglish };

static const char *const kEoB1MenuYesNoStringsAmigaEnglish[2] = {
	"Yes",
	"No"
};

static const StringListProvider kEoB1MenuYesNoStringsAmigaEnglishProvider = { ARRAYSIZE(kEoB1MenuYesNoStringsAmigaEnglish), kEoB1MenuYesNoStringsAmigaEnglish };

static const char *const kEoB1CharGuiStringsHpAmigaEnglish[2] = {
	"HP",
	"%3d of %-3d"
};

static const StringListProvider kEoB1CharGuiStringsHpAmigaEnglishProvider = { ARRAYSIZE(kEoB1CharGuiStringsHpAmigaEnglish), kEoB1CharGuiStringsHpAmigaEnglish };

static const char *const kEoB1CharGuiStringsWp1AmigaEnglish[2] = {
	"MISS",
	"HACK"
};

static const StringListProvider kEoB1CharGuiStringsWp1AmigaEnglishProvider = { ARRAYSIZE(kEoB1CharGuiStringsWp1AmigaEnglish), kEoB1CharGuiStringsWp1AmigaEnglish };

static const char *const kEoB1CharGuiStringsWrAmigaEnglish[4] = {
	"CAN'T",
	"REACH",
	"NO",
	"AMMO"
};

static const StringListProvider kEoB1CharGuiStringsWrAmigaEnglishProvider = { ARRAYSIZE(kEoB1CharGuiStringsWrAmigaEnglish), kEoB1CharGuiStringsWrAmigaEnglish };

static const char *const kEoB1CharGuiStringsSt1AmigaEnglish[6] = {
	"Swapping",
	"DEAD",
	"UNCONSCIOUS",
	"POISON (SLOW)",
	"POISONED",
	"PARALYZED"
};

static const StringListProvider kEoB1CharGuiStringsSt1AmigaEnglishProvider = { ARRAYSIZE(kEoB1CharGuiStringsSt1AmigaEnglish), kEoB1CharGuiStringsSt1AmigaEnglish };

static const char *const kEoB1CharGuiStringsInAmigaEnglish[4] = {
	"CHARACTER INFO",
	"ARMOR CLASS",
	"EXP",
	"LVL"
};

static const StringListProvider kEoB1CharGuiStringsInAmigaEnglishProvider = { ARRAYSIZE(kEoB1CharGuiStringsInAmigaEnglish), kEoB1CharGuiStringsInAmigaEnglish };

static const char *const kEoB1CharStatusStrings7AmigaEnglish[1] = {
	"%s no longer has giant strength.\r"
};

static const StringListProvider kEoB1CharStatusStrings7AmigaEnglishProvider = { ARRAYSIZE(kEoB1CharStatusStrings7AmigaEnglish), kEoB1CharStatusStrings7AmigaEnglish };

static const char *const kEoB1CharStatusStrings81AmigaEnglish[1] = {
	"%s feels the effects of poison!\r"
};

static const StringListProvider kEoB1CharStatusStrings81AmigaEnglishProvider = { ARRAYSIZE(kEoB1CharStatusStrings81AmigaEnglish), kEoB1CharStatusStrings81AmigaEnglish };

static const char *const kEoB1CharStatusStrings9AmigaEnglish[1] = {
	"%s is no longer paralyzed!\r"
};

static const StringListProvider kEoB1CharStatusStrings9AmigaEnglishProvider = { ARRAYSIZE(kEoB1CharStatusStrings9AmigaEnglish), kEoB1CharStatusStrings9AmigaEnglish };

static const char *const kEoB1CharStatusStrings131AmigaEnglish[1] = {
	"%s is %s!\r"
};

static const StringListProvider kEoB1CharStatusStrings131AmigaEnglishProvider = { ARRAYSIZE(kEoB1CharStatusStrings131AmigaEnglish), kEoB1CharStatusStrings131AmigaEnglish };

static const char *const kEoB1LevelGainStringsAmigaEnglish[1] = {
	"\x06\x06""%s has gained a level of experience.""\x06\x1F""\r"
};

static const StringListProvider kEoB1LevelGainStringsAmigaEnglishProvider = { ARRAYSIZE(kEoB1LevelGainStringsAmigaEnglish), kEoB1LevelGainStringsAmigaEnglish };

static const char *const kEoB1BookNumbersAmigaEnglish[5] = {
	"First",
	"Second",
	"Third",
	"Fourth",
	"Fifth"
};

static const StringListProvider kEoB1BookNumbersAmigaEnglishProvider = { ARRAYSIZE(kEoB1BookNumbersAmigaEnglish), kEoB1BookNumbersAmigaEnglish };

static const char *const kEoB1MageSpellsListAmigaEnglish[26] = {
	"",
	"Armor",
	"Burning Hands",
	"Detect Magic",
	"Magic Missile",
	"Read Magic",
	"Shield",
	"Shocking Grasp",
	"Invisibility",
	"Knock",
	"M's Acid Arrow",
	"Stinking Cloud",
	"Dispel Magic",
	"Fireball",
	"Flame Arrow",
	"Haste",
	"Hold Person",
	"Invisibility 10'",
	"Lightning Bolt",
	"Vampiric Touch",
	"Fear",
	"Ice Storm",
	"Stoneskin",
	"Cloudkill",
	"Cone of Cold",
	"Hold Monster"
};

static const StringListProvider kEoB1MageSpellsListAmigaEnglishProvider = { ARRAYSIZE(kEoB1MageSpellsListAmigaEnglish), kEoB1MageSpellsListAmigaEnglish };

static const char *const kEoB1ClericSpellsListAmigaEnglish[25] = {
	"",
	"Bless",
	"Cure Light Wnds",
	"Cause Light Wnds",
	"Detect Magic",
	"Protect-Evil",
	"Aid",
	"Flame Blade",
	"Hold Person",
	"Slow Poison",
	"Create Food",
	"Dispel Magic",
	"Magical Vestment",
	"Prayer",
	"Remove Paralysis",
	"Cure Serious",
	"Cause Serious",
	"Neutral-Poison",
	"Protect-Evil 10'",
	"Protect-Lightning",
	"Cure Critical",
	"Cause Critical",
	"Flame Strike",
	"Raise Dead",
	"Lay on Hands"
};

static const StringListProvider kEoB1ClericSpellsListAmigaEnglishProvider = { ARRAYSIZE(kEoB1ClericSpellsListAmigaEnglish), kEoB1ClericSpellsListAmigaEnglish };

static const char *const kEoB1SpellNamesAmigaEnglish[51] = {
	"",
	"armor",
	"burning hands",
	"detect magic",
	"magic missile",
	"shield",
	"shocking grasp",
	"invisibility",
	"melf's acid arrow",
	"stinking cloud",
	"dispel magic",
	"fireball",
	"flame arrow",
	"haste",
	"hold person",
	"invisibility 10' radius",
	"lightning bolt",
	"vampiric touch",
	"fear",
	"ice storm",
	"stoneskin",
	"cloudkill",
	"cone of cold",
	"hold monster",
	"bless",
	"cure light wounds",
	"cause light wounds",
	"detect magic",
	"protection from evil",
	"aid",
	"flame blade",
	"hold person",
	"slow poison",
	"create food",
	"dispel magic",
	"magical vestment",
	"prayer",
	"remove paralysis",
	"cure serious wounds",
	"cause serious wounds",
	"neutralize poison",
	"protection from evil 10' radius",
	"protection from lightning",
	"cure critical wounds",
	"cause critical wounds",
	"flame strike",
	"raise dead",
	"lay on hands",
	"",
	"",
	""
};

static const StringListProvider kEoB1SpellNamesAmigaEnglishProvider = { ARRAYSIZE(kEoB1SpellNamesAmigaEnglish), kEoB1SpellNamesAmigaEnglish };

static const char *const kEoB1MagicStrings1AmigaEnglish[6] = {
	"ABORT SPELL",
	"ABORT SPELL",
	"You must have a free hand for this spell.\r",
	"You can't have two of this spell type active.\r",
	"%s casts %s.\r",
	"ok\r"
};

static const StringListProvider kEoB1MagicStrings1AmigaEnglishProvider = { ARRAYSIZE(kEoB1MagicStrings1AmigaEnglish), kEoB1MagicStrings1AmigaEnglish };

static const char *const kEoB1MagicStrings2AmigaEnglish[3] = {
	"no effect\r",
	"%s has been disintegrated!\r",
	"The party has been hit by a death spell!\r"
};

static const StringListProvider kEoB1MagicStrings2AmigaEnglishProvider = { ARRAYSIZE(kEoB1MagicStrings2AmigaEnglish), kEoB1MagicStrings2AmigaEnglish };

static const char *const kEoB1MagicStrings3AmigaEnglish[6] = {
	"Cast spell on which character? ",
	"\rok\r",
	"\rSpell aborted.\r",
	"%s's %s spell expires.\r",
	"%s missed the monster.\r",
	"%s must be in the front ranks to hit!\r"
};

static const StringListProvider kEoB1MagicStrings3AmigaEnglishProvider = { ARRAYSIZE(kEoB1MagicStrings3AmigaEnglish), kEoB1MagicStrings3AmigaEnglish };

static const char *const kEoB1MagicStrings4AmigaEnglish[1] = {
	"no effect.\r"
};

static const StringListProvider kEoB1MagicStrings4AmigaEnglishProvider = { ARRAYSIZE(kEoB1MagicStrings4AmigaEnglish), kEoB1MagicStrings4AmigaEnglish };

static const char *const kEoB1MagicStrings6AmigaEnglish[1] = {
	"%s already has a high base armor class.\r"
};

static const StringListProvider kEoB1MagicStrings6AmigaEnglishProvider = { ARRAYSIZE(kEoB1MagicStrings6AmigaEnglish), kEoB1MagicStrings6AmigaEnglish };

static const char *const kEoB1MagicStrings7AmigaEnglish[5] = {
	"1ST",
	"2ND",
	"3RD",
	"4TH",
	"5TH"
};

static const StringListProvider kEoB1MagicStrings7AmigaEnglishProvider = { ARRAYSIZE(kEoB1MagicStrings7AmigaEnglish), kEoB1MagicStrings7AmigaEnglish };

static const char *const kEoB1MagicStrings8AmigaEnglish[3] = {
	"All spells on %s are dispelled.\r",
	"The party is already blessed!\r",
	"The aid spell fails!\r"
};

static const StringListProvider kEoB1MagicStrings8AmigaEnglishProvider = { ARRAYSIZE(kEoB1MagicStrings8AmigaEnglish), kEoB1MagicStrings8AmigaEnglish };

static const char *const kEoB1MagicStrings9AmigaEnglish[1] = {
	"%s is already protected by stoneskin.\r"
};

static const StringListProvider kEoB1MagicStrings9AmigaEnglishProvider = { ARRAYSIZE(kEoB1MagicStrings9AmigaEnglish), kEoB1MagicStrings9AmigaEnglish };

static const byte kEoB1ManDefAmigaEnglish[120] = {
	0x09, 0x0a, 0x02, 0x00, 0x09, 0x04, 0x03, 0x00,
	0x09, 0x06, 0x06, 0x00, 0x09, 0x03, 0x03, 0x00,
	0x09, 0x04, 0x02, 0x00, 0x09, 0x01, 0x02, 0x00,
	0x09, 0x05, 0x01, 0x00, 0x09, 0x09, 0x02, 0x00,
	0x09, 0x06, 0x02, 0x00, 0x23, 0x01, 0x05, 0x00,
	0x23, 0x02, 0x02, 0x00, 0x23, 0x03, 0x06, 0x00,
	0x23, 0x05, 0x01, 0x00, 0x23, 0x06, 0x03, 0x00,
	0x23, 0x07, 0x01, 0x00, 0x1a, 0x01, 0x01, 0x00,
	0x1a, 0x03, 0x02, 0x00, 0x1a, 0x06, 0x01, 0x00,
	0x24, 0x01, 0x03, 0x00, 0x24, 0x03, 0x04, 0x00,
	0x24, 0x03, 0x01, 0x00, 0x02, 0x04, 0x03, 0x00,
	0x02, 0x03, 0x03, 0x00, 0x02, 0x05, 0x03, 0x00,
	0x01, 0x01, 0x01, 0x00, 0x01, 0x05, 0x03, 0x00,
	0x01, 0x04, 0x03, 0x00, 0x0c, 0x02, 0x01, 0x00,
	0x0c, 0x03, 0x03, 0x00, 0x0c, 0x04, 0x02, 0x00
};

static const ByteProvider kEoB1ManDefAmigaEnglishProvider = { ARRAYSIZE(kEoB1ManDefAmigaEnglish), kEoB1ManDefAmigaEnglish };

static const char *const kEoB1ManWordAmigaEnglish[31] = {
	"attacks",
	"short",
	"line",
	"weapons",
	"certain",
	"rank",
	"rear",
	"can",
	"away",
	"dungeon",
	"cursor",
	"feature",
	"information",
	"displayed",
	"below",
	"around",
	"carefree",
	"gnomes",
	"clerics",
	"mystic",
	"pummel",
	"fitness",
	"using",
	"toughness",
	"wealth",
	"wizard",
	"officials",
	"hound",
	"disturbing",
	"flaming",
	""
};

static const StringListProvider kEoB1ManWordAmigaEnglishProvider = { ARRAYSIZE(kEoB1ManWordAmigaEnglish), kEoB1ManWordAmigaEnglish };

static const char *const kEoB1ManPromptAmigaEnglish[1] = {
	"\r\r\r\rOn the page with this symbol...\r\rFind line %d\rEnter word %d\r"
};

static const StringListProvider kEoB1ManPromptAmigaEnglishProvider = { ARRAYSIZE(kEoB1ManPromptAmigaEnglish), kEoB1ManPromptAmigaEnglish };

static const char *const kEoB1MonsterDistAttStringsAmigaEnglish[5] = {
	"%s is hit by a cause serious wounds spell!\r",
	"The party is hit with a psychic mind blast!\r",
	"paralyzed",
	"poisoned",
	"paralyzed"
};

static const StringListProvider kEoB1MonsterDistAttStringsAmigaEnglishProvider = { ARRAYSIZE(kEoB1MonsterDistAttStringsAmigaEnglish), kEoB1MonsterDistAttStringsAmigaEnglish };

static const char *const kEoB1NpcPresetsNamesAmigaEnglish[9] = {
	"Anya",
	"Beohram",
	"Kirath",
	"Ileria",
	"Tyrra",
	"Tod Uphill",
	"Taghor",
	"Dohrum",
	"Keirgar"
};

static const StringListProvider kEoB1NpcPresetsNamesAmigaEnglishProvider = { ARRAYSIZE(kEoB1NpcPresetsNamesAmigaEnglish), kEoB1NpcPresetsNamesAmigaEnglish };
